local M = {}

local fileHandler = require('scenario/cargames/fileHandler')

local function loadChampionshipData()
  --[[
  Retrieves the current championship data and returns it
  ]]--
  return fileHandler.getMiscAttribute("championship").data
end

local function loadFullChampionshipData()
  --[[
  Retrieves the full amount of championship data stored in the file and returns it
  ]]--
  return fileHandler.getMiscAttribute("championship")
end

local function saveChampionshipData(championshipData, engaged)
  --[[
  --Overwrites the old data with the new, and changes state if necessary
  ]]--
  fileHandler.setChampionshipInfo(championshipData, engaged)
end

local function isInChapionshipMode()
  --[[
  Returns true if the championship is being run, else returns false
  ]]--
  return fileHandler.getMiscAttribute("championship").engaged
end

local function getMedalPointConversion(medal)
  --[[
  Returns the amount of points each medal is worth
  ]]--
  if     medal == 1 then return 10
  elseif medal == 2 then return 12
  elseif medal == 3 then return 15
  elseif medal == 4 then return 20
  elseif medal == 5 then return 25
  else return 0
  end
end

local function reset()
  --[[
  Resets all of the variables and then overwrites the old data with the new
  ]]--
  local championshipData = {}
  championshipData.event = 0
  championshipData.theme = 0
  championshipData.eventScores = {}
  championshipData.overallScore = 0
  saveChampionshipData(championshipData, false)
end

local function endChampionship(champData, theme)
  --[[
  Ends the championship and saves the score to the appropiate theme
  ]]--
  local currentData = loadFullChampionshipData()
  local currentBestForTheme = currentData.themes[theme]

  --Update current best
  if champData.overallScore > currentBestForTheme then
    currentData.themes[theme] = champData.overallScore
  end

  saveChampionshipData(currentData, true)
  reset()
end

local function endEvent(scenarioData)
  --[[
  Handles the championship event ending
  ]]--
  local pts = getMedalPointConversion(scenarioData.medal)

  local champData = loadChampionshipData()

  --Check for old savefile and fix this before continuing
  if not champData.eventScores then
    reset()
    --Reload data
    champData = loadChampionshipData()
  end

  champData.overallScore = champData.overallScore + pts
  table.insert(champData.eventScores, pts)

  champData.theme = scenarioData.theme
  champData.event = scenarioData.event

  saveChampionshipData(champData, true)

  --Last event so end championship
  if scenarioData.event == 5 then
    endChampionship(champData, scenarioData.theme)
    return true, champData
  end

  return false, champData
end

M.isInChapionshipMode = isInChapionshipMode
M.saveChampionshipData = saveChampionshipData
M.loadChampionshipData = loadChampionshipData
M.loadFullChampionshipData = loadFullChampionshipData
M.reset = reset
M.getMessage = getMessage
M.endChampionship = endChampionship
M.endEvent = endEvent
return M
